@@ -8,8 +8,6 @@ import warnings
 warnings.filterwarnings("ignore")
 #---------------------------------------------------------------INSTALLATION---------------------------------------------------------#
 
-def install(package):
-    subprocess.check_call([sys.executable, "-m", "pip", "install", package])
 
 
 
@@ -54,8 +52,8 @@ nltk.download('punkt')
 
 #----------------------------------------FUNCTIONS-----------------------------------------------------------------------------#
 
-def load_file(df):
-    df = pd.read_json(df)
+def load_file(filename):
+    df = pd.read_json(filename)
     return df
 
 def merge_dataframes(df1, df2):
@@ -146,7 +144,7 @@ def node_list_conversion(df_graph):
     df_graph["screen_name_num"] = df_graph["screen_name"]
     for index, row in df_graph.iterrows():
         df_graph.loc[index, 'screen_name_num'] = my_dictionary[row["screen_name"]]
-        df_graph.loc[index, 'screen_name_num'] = my_dictionary[row["screen_name_mention"]]
+        df_graph.loc[index, 'screen_name_mention_num'] = my_dictionary[row["screen_name_mention"]]
     
     return df_graph, node_list
     
@@ -200,7 +198,6 @@ def leiden_alg (df_graph):
     
     
 def infMap_alg(df_graph):
-    print("A" )
     # Command line flags can be added as a string to Infomap
     im = Infomap("--two-level --directed")
     df_graph, node_list = structure_leiden(df_graph)
@@ -227,14 +224,12 @@ def infMap_alg(df_graph):
 def graph_algoritm_selected(df_graph,selection,node_list):
 
     len_nodeList = len(node_list)
-    print(type(selection))
-    print(selection)
-    if(selection =="1"):
+    if(selection =="1 - GirvanNewman"):
         df_algComu = girvanNewman_alg(node_list,df_graph)
-    elif(selection =="2"):
+    elif(selection =="2 - Leiden"):
         df_algComu = leiden_alg(df_graph)
-    elif(selection =="3"):
-        df_algComu = infMap_alg(df_graph)
+    #elif(selection =="3"):
+        #df_algComu = infMap_alg(df_graph)
     else:#default
         if(len_nodeList < 1000):
             df_algComu = girvanNewman_alg(node_list,df_graph)
@@ -379,7 +374,7 @@ def graph_json_values(df_graph, df_algComu):
     data['edges'] = []
     for i in range(len(df_graph)):
         data['edges'].append({
-          'screen_name': df_graph[col].iloc[i],
+          'screen_name': df_graph["screen_name"].iloc[i],
           'screen_name_mention': df_graph["screen_name_mention"].iloc[i],
           'iteration': str(df_graph["iteration"].iloc[i])
         })
@@ -456,17 +451,17 @@ def user_timeline_extraction(node_list, consumerKey, consumerSecret,accessToken,
                               "favourites_count": "favorites_count",
                               "full_text": "text"})
         df2 = metadata_extraction(df)
-        if path.exists(os.path.join(filepath,filename)):
-          df2.to_csv(path_or_buf =os.path.join(filepath,filename),mode="a", index=False, header=False)
+        if path.exists(os.path.join(filepath,filename+".csv")):
+          df2.to_csv(path_or_buf =os.path.join(filepath,filename+".csv"),mode="a", index=False, header=False)
         else:
-          df2.to_csv(path_or_buf = os.path.join(filepath,filename),index=False)         
+          df2.to_csv(path_or_buf = os.path.join(filepath,filename+".csv"),index=False)         
         if len(list_users_noInfo) !=0:
           nodes = pd.DataFrame()
           nodes["nodos"] = list_users_noInfo
-          if path.exists(os.path.join(filepath,"node_without_",filename)):
-            nodes.to_csv(path_or_buf = os.path.join(filepath,"node_without_"+filename), mode ="a",index=False, header=False)          
+          if path.exists(os.path.join(filepath,"node_without_",filename+".csv")):
+            nodes.to_csv(path_or_buf = os.path.join(filepath,"node_without_"+filename+".csv"), mode ="a",index=False, header=False)          
           else:
-             nodes.to_csv(path_or_buf = os.path.join(filepath,"node_without_"+filename), index=False)
+             nodes.to_csv(path_or_buf = os.path.join(filepath,"node_without_"+filename+".csv"), index=False)
         k = k+profile_iter        
         if ultima ==1:          
           ultima =2
@@ -1072,12 +1067,11 @@ def more_tweets_required(df,df_graph_features,consumerKey,consumerSecret,accessT
     df_evaluate= df_evaluate.drop(df_evaluate.index[delete_rows]).reset_index(drop=True)
     if len(node_list_moreData) >0:
         df_metadata_moreData, list_more_Data_noData = user_timeline_extraction(node_list_moreData,consumerKey,consumerSecret,accessToken,accessTokenSecret,filepath, filename,n_groups,save_by)
-        df_metadata_moreData = pd.read_csv(os.path.join(filepath,filename))
+        df_metadata_moreData = pd.read_csv(os.path.join(filepath,filename+".csv"))
         #df_metadata_moreData = text_to_list_features_conversor(df_metadata_moreData)
         df_metadata_moreData = advanced_features(df_metadata_moreData)
         df_metadata_moreData = merge_dataframes(df_metadata_moreData,df_graph_features)
         df_metadata_moreData = abnormal_categories_profiles(df_metadata_moreData)
-        print(len(df_metadata_moreData))
         delete_rows = []
         for i in range(len(df_metadata_moreData)):
           if (("More Data" in df_metadata_moreData["evaluate_NLP"].iloc[i]) | ("No" in df_metadata_moreData["evaluate_NLP"].iloc[i])): 
@@ -1089,7 +1083,14 @@ def more_tweets_required(df,df_graph_features,consumerKey,consumerSecret,accessT
 
 def contextual_analysis_profile(data, keyword_corpus, hashtag_corpus):  
     #To remember which name of the tw_per_day_list belongs each tweets
+    print(tw_per_day_list)
+    print("AAAAAAAAAAAAAA")
+    print(data["lang_days_list"])
     n_list_tw = range(0, len(data["tw_per_day_list"]))
+    print(n_list_tw)
+    print(len(data["text_tweets_days_list"]))
+    print(len(data["RT_days_list"]))
+    print(len(data["lang_days_list"]))
     aux = pd.DataFrame({'text':data["text_tweets_days_list"],'RT':data["RT_days_list"],'lang': data["lang_days_list"], 'n_list_tw':n_list_tw})
     tweets_df = pd.DataFrame()
     for i in range(len(aux)):
